v6

package
v0.2.0-rc.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Dec 18, 2024 License: Apache-2.0 Imports: 4 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var (
	UnbondingTypeKey    = collections.NewPrefix(57) // prefix for an index containing the type of unbonding operations
	UnbondingIDKey      = collections.NewPrefix(55) // key for the counter for the incrementing id for UnbondingOperations
	UnbondingIndexKey   = collections.NewPrefix(56) // prefix for an index for looking up unbonding operations by their IDs
	ValidatorUpdatesKey = collections.NewPrefix(97)
	HistoricalInfoKey   = collections.NewPrefix(80) // prefix for the historical info
)

Functions

func MigrateStore

func MigrateStore(ctx context.Context, store storetypes.KVStore, cdc codec.BinaryCodec) error

MigrateStore performs in-place store migrations from v5 to v6. It deletes the ValidatorUpdatesKey from the store.

Types

This section is empty.

Jump to